@@ -6,6 +6,7 @@ using Preferences
 
 include("verbosity.jl")
 include("utils.jl")
+include("verbspec_generation_macro.jl")
 
 # Export public API
 export AbstractVerbositySpecifier, AbstractVerbosityPreset, AbstractMessageLevel
@@ -15,5 +16,6 @@ export verbosity_to_int, verbosity_to_bool
 export SciMLLogger
 export set_logging_backend, get_logging_backend
 export None, Minimal, Standard, Detailed, All
+export @define_verbosity_specifier
 
 end
